@@ -1,9 +1,10 @@
 from django.db import models
 from django.urls import reverse
 from .choices import PDUUnitChoices
+from netbox.models import NetBoxModel
 
 
-class PDUConfig(models.Model):
+class PDUConfig(NetBoxModel):
     """PDU Configuration is contained within this model."""
 
     device_type = models.OneToOneField(to="dcim.DeviceType", on_delete=models.CASCADE, blank=True, null=True)
@@ -26,7 +27,7 @@ class PDUConfig(models.Model):
         return reverse('dcim:devicetype', args=[self.device_type.id])
 
 
-class PDUStatus(models.Model):
+class PDUStatus(NetBoxModel):
     """PDU Status is contained within this model."""
 
     device = models.OneToOneField(to="dcim.Device", on_delete=models.CASCADE, blank=True, null=True)
